pub fn build_evm<DB: Database>(db: DB) -> JitEvm<MainnetEvm<MainnetContext<DB>>>Expand description
Build a mainnet EVM wrapped in [JitEvm] so that calls to known code hashes
are dispatched to compiled functions instead of the interpreter.
pub fn build_evm<DB: Database>(db: DB) -> JitEvm<MainnetEvm<MainnetContext<DB>>>Build a mainnet EVM wrapped in [JitEvm] so that calls to known code hashes
are dispatched to compiled functions instead of the interpreter.